@@ -62,9 +62,9 @@
 #'
 
 tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size = .5,
-                          .geom_point = FALSE, .point_size = 1,
-                          .geom_rug = FALSE, .geom_smooth = FALSE,
-                          .geom_jitter = FALSE, .interactive = FALSE) {
+                                     .geom_point = FALSE, .point_size = 1,
+                                     .geom_rug = FALSE, .geom_smooth = FALSE,
+                                     .geom_jitter = FALSE, .interactive = FALSE) {
 
     # Plot type ----
     plot_type <- tolower(as.character(.plot_type))
@@ -124,7 +124,7 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
         "Parameters: ", if (atb$all$tibble_type == "tidy_gaussian") {
             paste0("Mean: ", toString(atb$.param_list$.mean), " - SD: ", toString(atb$.param_list$.sd))
         } else if (atb$all$tibble_type == "tidy_gamma") {
-            paste0("Shape: ", toString(atb$.param_list$.shape), " - Rate: ", toString(atb$.param_list$.rate))
+            paste0("Shape: ", toString(atb$.param_list$.shape), " - Scale: ", toString(atb$.param_list$.scale))
         } else if (atb$all$tibble_type == "tidy_beta") {
             paste0("Shape1: ", toString(atb$.param_list$.shape1), " - Shape2: ", toString(atb$.param_list$.shape2), " - NCP: ", toString(atb$.param_list$.ncp))
         } else if (atb$all$tibble_type %in% c("tidy_poisson", "tidy_zero_truncated_poisson")) {
@@ -162,7 +162,7 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
         } else if (atb$all$tibble_type %in% c("tidy_pareto", "tidy_inverse_pareto")) {
             paste0("Shape: ", toString(atb$.param_list$.shape), " - Scale: ", toString(atb$.param_list$.scale))
         } else if (atb$all$tibble_type %in% c("tidy_generalized_pareto",
-                                          "tidy_burr","tidy_inverse_burr")){
+                                              "tidy_burr","tidy_inverse_burr")){
             paste0(
                 "Shape1: ", toString(atb$.param_list$.shape1), " - ",
                 "Shape2: ", toString(atb$.param_list$.shape2), " - ",
@@ -207,7 +207,7 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
         "bottom"
     }
 
-    if (plot_type == "density") {
+    if (plot_type == "density" & atb$all$distribution_family_type == "continuous") {
         plt <- data_tbl %>%
             ggplot2::ggplot(
                 ggplot2::aes(x = dx, y = dy, group = interaction(dist_name, sim_number), color = dist_name)
@@ -220,6 +220,22 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
                 color = "Simulation"
             ) +
             ggplot2::theme(legend.position = leg_pos)
+    } else if (plot_type == "density" & atb$all$distribution_family_type == "discrete"){
+        plt <- data_tbl %>%
+            ggplot2::ggplot(
+                ggplot2::aes(x = y, group = interaction(dist_name, sim_number), color = dist_name)
+            ) +
+            ggplot2::geom_histogram(
+                alpha = 0.318, color = "#e9ecef", bins = max(unique(data_tbl$y)) + 1,
+                position = "identity"
+            ) +
+            ggplot2::theme_minimal() +
+            ggplot2::labs(
+                title = "Histogram Plot",
+                subtitle = sub_title,
+                fill = "Simulation"
+            ) +
+            ggplot2::theme(legend.position = leg_pos)
     } else if (plot_type == "quantile") {
         plt <- data_tbl %>%
             ggplot2::ggplot(
@@ -279,6 +295,8 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
     }
 
     if (.geom_smooth) {
+        max_dy <- max(data_tbl$dy)
+
         plt <- plt +
             ggplot2::geom_smooth(
                 ggplot2::aes(
@@ -287,7 +305,8 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
                 se = FALSE,
                 color = "black",
                 linetype = "dashed"
-            )
+            ) +
+            ggplot2::xlim(0, max_dy)
     }
 
     if (.geom_jitter) {
